<?php
/*
Plugin Name: DiviFlash
Plugin URI:  http://www.diviflash.com
Description: Module pack for Divi
Version:     1.1.1
Author:      DiviFlash
Author URI:  http://www.diviflash.com
License:     GPL2
License URI: https://www.gnu.org/licenses/gpl-2.0.html
Text Domain: divi_flash
Domain Path: /languages
*/

if(!defined('DIFL_MAIN_DIR')) {
	define('DIFL_MAIN_DIR', __DIR__);
}
if(!defined('DIFL_ADMIN_DIR')) {
	define('DIFL_ADMIN_DIR', trailingslashit(plugin_dir_url(__FILE__)) . 'admin/');
}
if(!defined('DIFL_ADMIN_DIR_PATH')) {
	define('DIFL_ADMIN_DIR_PATH', plugin_dir_path( __FILE__ ) . 'admin/');
}
if(!defined('DIFL_PUBLIC_DIR')) {
	define('DIFL_PUBLIC_DIR', trailingslashit(plugin_dir_url(__FILE__)) . 'public/');
}
if(!defined('DIFL_PUBLIC_DIR_PATH')) {
	define('DIFL_PUBLIC_DIR_PATH', plugin_dir_path( __FILE__ ) . 'public/');
}
if(!defined('DIFL_MAIN_FILE_PATH')) {
	define('DIFL_MAIN_FILE_PATH', __FILE__);
}
if(!defined('DIFL_VERSION')) {
	define('DIFL_VERSION','1.1.1');
}

if ( ! defined( 'DIFL_BASENAME' ) ) {
	define( 'DIFL_BASENAME', plugin_basename( __FILE__ ) );
}

/**
 * The core plugin class that is used to define internationalization,
 * admin-specific hooks, and public-facing site hooks.
 */
require plugin_dir_path( __FILE__ ) . 'includes/class-diviflash-init.php';
/**
 * Begins execution of the plugin.
 *
 * Since everything within the plugin is registered via hooks,
 * then kicking off the plugin from this point in the file does
 * not affect the page life cycle.
 *
 * @since    1.0.0
 */
function run_diviflash() {

	$plugin = new DiviFlashInit();
	$plugin->run();

}

run_diviflash();

/**
 * Auto-deactivate DiviFlash Plugin if inactive Divi/Extra child or parent theme or Divi Builder
 *
 */
function df_deactivate_if_theme_builder_uses() {
	// Don't do anything if the user isn't logged in
	if ( ! is_user_logged_in() ) {
		return;
	}

	$current_template = esc_attr( get_option( 'template' ) );

	// Check whether the active (or parent) theme is Divi or Extra
	if ( in_array( $current_template, array( 'Divi', 'Extra' ) ) ) {
         
		return;
	}else{
		// Need check Divi Builder Exist
 		include_once( ABSPATH . 'wp-admin/includes/plugin.php' );
		if(is_plugin_active('divi-builder/divi-builder.php')){
           return;
		}
	}

	if ( current_user_can( 'activate_plugins' ) ) {
		add_action( 'admin_notices', 'df_auto_deactivate_notice' );
		add_action( 'admin_init', 'df_auto_deactivate' );
	}
}
add_action( 'plugins_loaded', 'df_deactivate_if_theme_builder_uses' );

/**
 * Deactivate this plugin
 *
 * @since ??
 */
function df_auto_deactivate() {
	deactivate_plugins( DIFL_BASENAME );
}

/**
 * Print a WP Admin notice when Divi Flash has deactivated
 *
 * @since ??
 */
function df_auto_deactivate_notice() {
	$classes = 'notice notice-warning is-dismissible';
	$message = __( 'You should activate Divi theme / Extra theme / Divi Builder first for activating diviflash.', 'et_builder' );

	printf( '<div class="%1$s"><p>%2$s</p></div>', esc_attr( $classes ), esc_html( $message ) );

	if ( isset( $_GET['activate'] ) ) { // phpcs:ignore WordPress.Security.NonceVerification
		unset( $_GET['activate'] ); // phpcs:ignore WordPress.Security.NonceVerification
	}
}