<?php

trait Df_Cpt_Taxonomy_Support {
    public $df_post_types = array(
        'select'    => 'Select post type'
    );
    public $df_taxonomies;
    public $tax_settings = array();
    public $term_settings = array();
    public $tab_slug;
    public $toggle_slug;
    public $selected_post_type = '';
    public $selected_taxonomy = '';
    public $selected_terms = '';
    public $tax_show_if = array();
    public $terms_show_if = array();
    /**
     * Initialise the class
     * 
     */
    public function init_cpt_tax(
        $tab_slug = 'general', 
        $toggle_slug = 'settings',
        $tax_show_if = array(),
        $terms_show_if = array() 
    ) {
        $this->tab_slug = $tab_slug;
        $this->toggle_slug = $toggle_slug;
        $this->tax_show_if = $tax_show_if;
        $this->terms_show_if = $terms_show_if;

        $this->df_post_types = array_merge($this->df_post_types, $this->df_get_post_types(false, false));
        $this->df_taxonomies = $this->df_tax_for_cpts();
        $this->tax_settings = $this->df_get_tax_settings();
    }

    /**
     * Genarate taxonomy settings for 
     * each taxonomy
     * 
     * @return array
     */
    public function df_get_tax_settings() {
        $tax_settings = array();
        foreach($this->df_taxonomies as $cpt_slug => $tax_array) {
            $tax_settings['tax_for_' . $cpt_slug ] = $this->df_tax_settings($tax_array, $cpt_slug);
        }
        return $tax_settings;
    }

    /**
     * Generate taxonomy array for 
     * a post type
     * 
     * @param string $cpt
     * @param array $tax_array
     * 
     * @return array
     */
    public function df_tax_settings($tax_array, $tax_slug) {
        $df_tax_settings = array(
            'label'             => esc_html__('Select Taxonomy', 'divi_flash'),
            'type'              => 'select',
            'options'           => $tax_array,
            'default'           => 'select_tax',
            'tab_slug'          => $this->tab_slug,
            'toggle_slug'       => $this->toggle_slug,
            'show_if_not'       => array(
                'use_current_loop' => 'on',
                'post_type' => 'select'
            )
        );
        $show_if = array(
            'post_type'  => $tax_slug
        );
        $show_if = array_merge($show_if, $this->tax_show_if);
        $df_tax_settings['show_if'] = $show_if;
        
        return $df_tax_settings;
    }

    /**
     * Get taxonomies for post types
     * 
     * @return array
     */
    public function df_tax_for_cpts() {
        $post_types = $this->df_post_types;
        $tax_arrays = array();
        foreach( $post_types as $name => $label ) {
            $tax_arrays[$name] = $this->df_get_taxonomies($name);
        }
        return $tax_arrays;
    }

    /**
     * Get Taxonomiy list
     * 
     * @param string $post_type
     * @return array
     */
    public function df_get_taxonomies($post_type) {
        $taxonomies = get_object_taxonomies( $post_type );
        $tax_array = array();
        if(!empty($taxonomies)) {
            $tax_array['select_tax'] = 'Select Taxonomy';
            foreach ( $taxonomies as $key => $texonomy ) {
                $tax_array[$texonomy] = $texonomy;
                $this->df_get_terms($texonomy, $post_type);
            }
        } else {
            $tax_array['select_tax'] = 'No Taxonomy Found';
        }

        return $tax_array;
    }

    /**
     * Generate term settings for each taxonomies
     * 
     * @param String $texonomy
     * @param String $post_type
     * @return null
     */
    public function df_get_terms($texonomy, $post_type) {
        $this->term_settings['terms_'.$texonomy] = $this->df_term_settings($texonomy, $post_type);
    }

    /**
     * Term settings
     * 
     * @param String $term_slug
     * @param String $post_type
     * @return array
     */
    public function df_term_settings($term_slug, $post_type) {
        return array(
            'label'            => esc_html__( 'Include Texonomies', 'divi_flash' ),
            'type'             => 'categories',
            'renderer_options' => array(
                'use_terms'    => true,
                'term_name'    => $term_slug,
            ),
            'taxonomy_name'    => $term_slug,
            'toggle_slug'      => 'settings',
            'show_if'         => array(
                'post_display'          => 'by_tax',
                'post_type'             => $post_type,
                'tax_for_'.$post_type   => $term_slug
            ),
            'show_if_not'       => array(
                'use_current_loop' => 'on'
            )
        );
    }

    /**
    * Get the list of registered Post Types options.
    *
    * @param boolean|callable $usort Comparision callback.
    * @param boolean          $require_editor Optional. Whether to retrieve only post type that has editor support.
    *
    * @return array
    */
    function df_get_post_types( $usort = false, $require_editor = true ) {
        $require_editor_key = $require_editor ? '1' : '0';
        $key                = "df_get_registered_post_type_options:{$require_editor_key}";
    
        if ( ET_Core_Cache::has( $key ) ) {
            return ET_Core_Cache::get( $key );
        }
    
        $blocklist = et_builder_get_blocklisted_post_types();
        $allowlist = et_builder_get_third_party_post_types();
    
        // Extra and Library layouts shouldn't appear in Theme Options as configurable post types.
        /**
         * Get array of post types to prevent from appearing as options for builder usage.
         *
         * @since 4.0
         *
         * @param string[] $blocklist Post types to blocklist.
         */
        $blocklist      = array_merge(
            $blocklist,
            array(
                'et_pb_layout',
                'layout',
                'post',
                'attachment',
                'page'
            )
        );
        $blocklist      = apply_filters( 'et_builder_post_type_options_blocklist', $blocklist );
        $raw_post_types = get_post_types(
            array(
                'show_ui' => true,
            ),
            'objects'
        );
        $post_types     = array();
    
        foreach ( $raw_post_types as $post_type ) {
            $is_allowlisted  = in_array( $post_type->name, $allowlist, true );
            $is_blocklisted  = in_array( $post_type->name, $blocklist, true );
            $supports_editor = $require_editor ? post_type_supports( $post_type->name, 'editor' ) : true;
            $is_public       = et_builder_is_post_type_public( $post_type->name );
    
            if ( ! $is_allowlisted && ( $is_blocklisted || ! $supports_editor || ! $is_public ) ) {
                continue;
            }
    
            $post_types[] = $post_type;
        }
    
        if ( $usort && is_callable( $usort ) ) {
            usort( $post_types, $usort );
        }
    
        $post_type_options = array_combine(
            wp_list_pluck( $post_types, 'name' ),
            wp_list_pluck( $post_types, 'label' )
        );
    
        // did_action() actually checks if the action has started, not ended so we
        // need to check that we are not currently doing the action as well.
        if ( did_action( 'init' ) && ! doing_action( 'init' ) ) {
            // Only cache the value after init is done when we are sure all
            // plugins have registered their post types.
            ET_Core_Cache::add( $key, $post_type_options );
        }
    
        if(empty($post_type_options)) {
            $post_type_options = array(
                'not_found' => 'No Custom Post Type Found'
            );
        }
    
        return $post_type_options;
    }
    /**
     * Get taxonomy values by selected post type
     * and selected taxonomy
     * 
     * @return void
     */
    public function get_taxonomy_values(){
        $this->selected_post_type = $this->props['post_type'];

        $this->selected_taxonomy = $this->props['tax_for_'.$this->selected_post_type];

        $this->selected_terms = isset($this->props['terms_'.$this->selected_taxonomy]) ? $this->props['terms_'.$this->selected_taxonomy] : '';

    }
}