<?php
/**
 * Allowed Html for text input.
 * Used by wordpress wp_kses() function
 * 
 * @return Array
 */
function df_allowed_html_for_text_input() {
    return $allowed_html = array(
        'br' => array(),
        'em' => array(
            'style' => array()
        ),
        'strong' => array(
            'style' => array()
        ),
        'b' => array(
            'style' => array()
        ),
        'p' => array(
            'style' => array()
        ),
        'ul' => array(
            'style' => array(),
            'class' => array()
        ),
        'li' => array(
            'style' => array(),
            'class' => array()
        ),
        'ol' => array(
            'style' => array(),
            'class' => array()
        ),
        'a' => array(
            'style' => array(),
            'class' => array(),
            'href'  => array()
        )
    );
}

/**
 * VB HTML on AJAX request for CFSeven
 * @return json response
 */
add_action( 'wp_ajax_df_cfseven_requestdata', 'df_cfseven_requestdata' );
function df_cfseven_requestdata() {
    global $paged, $post;

    $data = json_decode(file_get_contents('php://input'), true);
    if (! wp_verify_nonce( $data['et_admin_load_nonce'], 'et_admin_load_nonce' )) {
        wp_die();
    }
    $options = $data['props'];

    $args = array(
        'post_type' => 'wpcf7_contact_form',
    );

    if ($options['cf7_forms'] === 'default') {
        $contact_forms = "Please select an contact form!";
    } else {
        $contact_forms = do_shortcode('[contact-form-7 id="'.$options['cf7_forms'].'" ]');
    }
    
    $posts = $contact_forms;
    wp_send_json_success($posts);
}

/**
 * VB HTML on AJAX request for WPForms
 * @return json response
 * 
 */
add_action( 'wp_ajax_df_wpforms_requestdata', 'df_wpforms_requestdata' );
function df_wpforms_requestdata() {
    global $paged, $post, $wp_scripts, $wp_styles;

    $data = json_decode(file_get_contents('php://input'), true);
    if (! wp_verify_nonce( $data['et_admin_load_nonce'], 'et_admin_load_nonce' )) {
        wp_die();
    }
    $options = $data['props'];

    unset( $wp_scripts->registered );

    $preview_template = DIFL_MAIN_DIR . "/template/preview.php";

    $shortcode = '[wpforms id="'.$options['wpforms'].'"]';

    ob_start();
    echo et_core_esc_wp(include($preview_template));
    $wpforms = ob_get_clean();

    $form = [
        'content'   => $wpforms,
        'styles'    => $wp_styles,
        'scripts'   => $wp_scripts
    ];
    wp_send_json_success($form);
}

function df_wpforms_et_builder_load_actions( $actions ) {
	$actions[] = 'df_wpforms_requestdata';

	return $actions;
}
add_filter( 'et_builder_load_actions', 'df_wpforms_et_builder_load_actions' );

/**
 * Add URL fields to media uploader
 *
 * @param $form_fields array, fields to include in attachment form
 * @param $post object, attachment record in database
 * @return $form_fields, modified form fields
 */
function df_ig_add_attachment_field( $form_fields, $post ) {

    $form_fields['df-ig-url'] = array(
        'label' => 'URL',
        'input' => 'url',
        'value' => esc_attr(get_post_meta( $post->ID, 'df_ig_url', true )),
        'helps' => 'Add URL',
    );
 
    return $form_fields;
}
 
add_filter( 'attachment_fields_to_edit', 'df_ig_add_attachment_field', 10, 2 );
 
/**
 * Save values URL in media uploader
 *
 * @param $post array, the post data for database
 * @param $attachment array, attachment fields from $_POST form
 * @return $post array, modified post data
 */
function df_ig_save_attachment_field_save( $post, $attachment ) {
 
    if( isset( $attachment['df-ig-url'] ) ) {
        update_post_meta( $post['ID'], 'df_ig_url', esc_url( $attachment['df-ig-url'] ) );
    }

    return $post;
}
 
add_filter( 'attachment_fields_to_save', 'df_ig_save_attachment_field_save', 10, 2 );


// Active Mim Type upload 
add_filter( 'mime_types', 'df_mime_types' );
function df_mime_types( $existing_mimes ) {
    
    $existing_mimes['csv'] = 'text/csv';
    return $existing_mimes;
}
// Image Alternative Text from url
function df_image_alt_by_url( $image_url ) {
    global $wpdb;
    // phpcs:disable WordPress.DB.PreparedSQLPlaceholders.UnquotedComplexPlaceholder
    $attachment = $wpdb->get_col( $wpdb->prepare("SELECT ID FROM %1s WHERE guid='%2s';", esc_sql($wpdb->posts) , esc_sql($image_url) ) ); //phpcs:ignore WordPress.DB.DirectDatabaseQuery
    // phpcs:enable WordPress.DB.PreparedSQLPlaceholders.UnquotedComplexPlaceholder
    if($wpdb->last_error !== '')
        return false;
    //$attachment = $wpdb->get_col($query); 

    if(count ($attachment) < 1)
        return false;
    $image_id  = intval($attachment[0]);
    $image_alt = get_post_meta( $image_id , '_wp_attachment_image_alt', true );

    return $image_alt; 
}

/**
 * Required functions
 * 
 */
require_once( DIFL_MAIN_DIR . '/includes/functions/df_dashboard.php');
require_once( DIFL_MAIN_DIR . '/includes/functions/df_advanced_datatable_functions.php');
require_once( DIFL_MAIN_DIR . '/includes/functions/df_instagram.php');
require_once( DIFL_MAIN_DIR . '/includes/functions/df_imagegallery_functions.php');
require_once( DIFL_MAIN_DIR . '/includes/functions/df_jsgallery_functions.php');
require_once( DIFL_MAIN_DIR . '/includes/functions/df_packery_functions.php');
require_once( DIFL_MAIN_DIR . '/includes/functions/df_post_functions.php');
require_once( DIFL_MAIN_DIR . '/includes/functions/df_cpt_functions.php');


